/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import java.io.File;


/**
 * This class is derived from {@link Server} class and is the base class for all classes representing an application
 * server to be used while running tests. Those classes will have corresponding elements in the Ant build file.
 * <p/>
 * <b>Supported attributes:</b> <ul><li><tt>warfile</tt> - implementation defines if is required, defines a war file to
 * be deployed during server startup</li> <li><tt>earfile</tt> - implementation defines if is required, defines an ear
 * file deployed during server startup</li> </ul>
 * <p/>
 * <b>Note:</b> <tt>warfile</tt> and <tt>earfile</tt> can not be specified together
 * <p/>
 * This class is mutable, i.e. not thread-safe.
 *
 * @author real_vg, TCSDEVELOPER
 * @version 1.0
 */
public abstract class ApplicationServer extends Server {

    /**
     * This field represents the <tt>warfile</tt> attribute,which specifies the web application archive that should be
     * tested. The archive must already contain everything needed for running tests. Derived classes specify if this
     * attribute is required. Can't be set together with the <tt>earfile</tt> attribute. The field is initialized to
     * <tt>null</tt> and set via the {@link #setWarFile(java.io.File)} method.
     */
    private File warFile = null;

    /**
     * This field represents the <tt>earfile</tt> attribute, which specifies the enterprise application archive that
     * should be tested. The archive must contain a web module that already contains everything needed for running tests
     * Derived classes specify if this attribute is required. Can't be set together with <tt>warfile</tt> attribute. The
     * field is initialized to <tt>null</tt> and set via the {@link #setEarFile(java.io.File)} method.
     */
    private File earFile = null;

    /**
     * Creates an ApplicationServer instance. The type of server represented by the class is specified. Type is a string
     * like <tt>"tomcat5x"</tt>, which actually specifies the name and version of the server.
     *
     * @param type the type of the server
     *
     * @throws org.apache.tools.ant.BuildException
     *                                  if the type of the server is unrecognized, or any other error happens
     * @throws IllegalArgumentException if type is <tt>null</tt>
     */
    protected ApplicationServer(final String type) {
        //arg checking done in super method
        super(type);
    }

    /**
     * This method sets the value of the <tt>warfile</tt> attribute, which specifies the web application archive that
     * should be tested. The archive must already contain everything needed for running tests.
     *
     * @param warFile the value of the <tt>warfile</tt> attribute to be set
     */
    public void setWarFile(final File warFile) {
        this.warFile = warFile;
    }

    /**
     * This method returns the value of the <tt>warfile</tt> attribute, which specifies the web application archive that
     * should be tested. The archive must already contain everything needed for running tests.
     *
     * @return the value of the <tt>warfile</tt> attribute
     */
    public File getWarFile() {
        return warFile;
    }

    /**
     * This method sets the value of the <tt>earfile</tt> attribute, which specifies the enterprise application archive
     * that should be tested. The archive must contain a web module that already contains everything needed for running
     * tests.
     *
     * @param earFile the value of the <tt>earfile</tt> attribute to be set
     */
    public void setEarFile(final File earFile) {
        this.earFile = earFile;
    }

    /**
     * This method returns the value of the <tt>earfile</tt> attribute, which specifies the enterprise application
     * archive that should be tested. The archive must contain a web module that already contains everything needed for
     * running tests.
     *
     * @return the value of the <tt>earfile</tt> attribute
     */
    public File getEarFile() {
        return earFile;
    }
}
