/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import org.apache.tools.ant.BuildException;

import java.util.Map;


/**
 * A CredentialProperty represents nested element of the <tt>credentials</tt> element. This nested element represents
 * single property from the property map. The name of nested element represents the property key, the <tt>value</tt>
 * attribute - property value.
 * <p/>
 * This class is mutable, i.e. not thread-safe.
 *
 * @author real_vg, TCSDEVELOPER
 * @version 1.0
 */
public class CredentialProperty {

    /**
     * This field is the name of property, represented by this element. It is initialized in the constructor.
     */
    private final String name;

    /**
     * This field holds the property map this property belongs to. It is initialized in the constructor.
     */
    private final Map propertyMap;

    /**
     * Creates a CredentialProperty instance. The name of property and the property map the property should belong to
     * are specified.
     *
     * @param name        the name of the property
     * @param propertyMap the property map the property should belong to
     *
     * @throws IllegalArgumentException if name or propertyMap is <tt>null</tt> or name is empty (trim'd) string
     */
    public CredentialProperty(final String name, final Map propertyMap) {
        if (name == null) {
            throw new IllegalArgumentException("The parameter named [name] was null.");
        }
        if (propertyMap == null) {
            throw new IllegalArgumentException("The parameter named [propertyMap] was null.");
        }
        if (name.trim().length() == 0) {
            throw new IllegalArgumentException("The parameter named [name] was an empty String.");
        }

        this.name = name;
        this.propertyMap = propertyMap;
    }

    /**
     * This method sets the value of the <tt>value</tt> attribute, which represents the value of the property. This
     * method adds property to the property map.
     *
     * @param value the value of the property to be set
     *
     * @throws BuildException in case a property with the same name has already been specified before
     */
    public void setValue(final String value) {
        if (propertyMap.containsKey(name)) {
            throw new BuildException(
                "Duplicate name: The credentials property with the name [" + name + "] existed more than once.");
        }

        // as of https://software.topcoder.com/forum/c_forum_message.jsp?f=20015788&r=21577871
        // empty string is a valid value
        propertyMap.put(name, value);
    }
}
