/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import java.lang.reflect.Field;


/**
 * This utility class contains some code and constants used in the test cases of the component.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class TestingUtils {
    /**
     * This is the path to a valid prepared war file to be run in a container.
     */
    public static final String VALID_PREPARED_WAR_FILE = "test_files/dummyFiles/valid.war";
    /**
     * This is the path to a valid unprepared war file to be prepared by the component.
     */
    public static final String VALID_UNPREPARED_WAR_FILE = "test_files/dummyFiles/unprepared.war";
    /**
     * This is the path to a valid unprepared ear file to be prepared by the component.
     */
    public static final String VALID_UNPREPARED_EAR_FILE = "test_files/dummyFiles/unprepared.ear";
    /**
     * This is the name of the system property from which the tomcat home directory used in test cases is read.
     */
    private static final String TESTCASES_TOMCAT_HOME_PROPERTY_NAME = "testcases.tomcatHome";
    /**
     * This is the name of the system property from which the tomcat port used in test cases is read.
     */
    private static final String TESTCASES_TOMCAT_PORT_PROPERTY_NAME = "testcases.tomcatPort";
    /**
     * Thi is the default value used as tomcat port if no tomcat port has been specified as system property.
     */
    private static final int DEFAULT_PORT = 12345;

    /**
     * This is a private constructor to avoid instantiation of this utility class.
     */
    private TestingUtils() {
    }

    /**
     * This utility method can be used to retrieve the value of an (even private) instance's field.
     *
     * @param instance the instance to retrieve the field value from
     * @param name     the name of the field whose value to retrieve
     *
     * @return the value retrieved from the instance's field
     *
     * @throws Exception in case the retrieval fails
     */
    public static Object getFieldValue(final Object instance, final String name) throws Exception {
        Class aClass = instance.getClass();
        Field field = null;

        while (field == null && aClass != null) {
            try {
                field = aClass.getDeclaredField(name);
            } catch (NoSuchFieldException e) {
                // this exception is ignored and later reproduced in
                // case no field has been found the whole way up
                // the class hierarchy of the instance
            }
            aClass = aClass.getSuperclass();
        }
        if (field == null) {
            throw new NoSuchFieldException("Field [" + name + "] not found in [" + instance + "].");
        }
        field.setAccessible(true);
        return field.get(instance);
    }

    /**
     * This method retrieves the Tomcat home directory configured to be used when running container test cases.
     *
     * @return the tomcat home directory path to be used for the test cases
     */
    public static String getValidTomcatHomeDir() {
        String s = System.getProperty(TESTCASES_TOMCAT_HOME_PROPERTY_NAME);
        if (s == null || s.trim().length() == 0) {
            throw new IllegalStateException(
                "The system property  [" + TESTCASES_TOMCAT_HOME_PROPERTY_NAME + "] must be "
                    + "set to a valid Tomcat 5.x installation home for the test cases to succeed.");
        }
        return s;
    }

    /**
     * This method retrieves the tomcat port to be used when running container test cases.
     *
     * @return the tomcat port to be used when running container test cases
     */
    public static int getPort() {
        String s = System.getProperty(TESTCASES_TOMCAT_PORT_PROPERTY_NAME);
        if (s != null && s.trim().length() > 0) {
            try {
                return Integer.parseInt(s.trim());
            } catch (NumberFormatException e) {
                throw new IllegalStateException("The system property [" + TESTCASES_TOMCAT_PORT_PROPERTY_NAME
                    + "] must be set to a value parseable into an int, but was [" + s + "].");
            }
        } else {
            return DEFAULT_PORT;
        }
    }
}
